"""Public request processing service client."""

from fred_api.public_request.service_public_request_processing_grpc_pb2 import (
    InvalidateRequest as InvalidateRequestMsg,
    ResolveRequest as ResolveRequestMsg,
)
from fred_api.public_request.service_public_request_processing_grpc_pb2_grpc import (
    PublicRequestProcessingStub,
)
from frgal.aio import AsyncGrpcClient

from .common import PublicRequestId
from .decoder import PublicRequestDecoder


class PublicRequestProcessingClient(AsyncGrpcClient):
    """Public request processing service client."""

    stub_cls = PublicRequestProcessingStub
    decoder_cls = PublicRequestDecoder

    async def resolve(self, public_request_id: PublicRequestId, resolving_id: str) -> None:
        """Resolve the public request with logging entry.

        Args:
            public_request_id: Identifier of public request.
            resolving_id: Log entry ID to store with the event.

        Returns:
            none (on success)

        Raises:
            PublicRequestDoesNotExist: Request with the identifier not found.
            CannotBeProcessed: The request not in open state or not resolvable.
        """
        request = ResolveRequestMsg()
        request.public_request_id.value = public_request_id
        request.resolving_id.value = resolving_id
        await self.call("resolve", request)

    async def invalidate(self, public_request_id: PublicRequestId, resolving_id: str) -> None:
        """Invalidate the public request with logging entry.

        Args:
            public_request_id: Identifier of public request.
            resolving_id: Log entry ID to store with the event.

        Returns:
            none (on success)

        Raises:
            PublicRequestDoesNotExist: Request with the identifier not found.
            CannotBeProcessed: The request not in open state.
        """
        request = InvalidateRequestMsg()
        request.public_request_id.value = public_request_id
        request.resolving_id.value = resolving_id
        await self.call("invalidate", request)
